from youtubeRenderer.custom_exception import InvalidURLException
from youtubeRenderer.logger import logger
import re 
from IPython.display import HTML, display




def render_youtube_video(url: str, width: int = 780, height: int = 440):
    try:
        regex = r"(?:v=|\/)([0-9A-Za-z_-]{11}).*"
        match = re.search(regex, url)

        if not match:
            raise InvalidURLException(f"Invalid YouTube URL: {url}")
        
        video_id = match.group(1)

        embed_url = f"https://www.youtube-nocookie.com/embed/{video_id}"


        iframe = f"""
        <iframe width="{width}" height="{height}" 
        src="{embed_url}" 
        title="YouTube video player" 
        frameborder="0" 
        allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" 
        referrerpolicy="strict-origin-when-cross-origin" 
        allowfullscreen>
        </iframe>
        """

        display(HTML(iframe))
        logger.info("YouTube video rendered successfully.")
        
        return "success"

    except Exception as e:
        raise e


import os 
import logging 
import sys 

logging_str = "[%(asctime)s: %(levelname)s: %(module)s: %(message)s]"
log_dir = "./logs"
log_filepath = os.path.join(log_dir,"running_logs.log") 
os.makedirs(log_dir,exist_ok=True) 

logging.basicConfig(
    level = logging.INFO,
    format=logging_str,
    handlers=[
        logging.FileHandler(log_filepath),
        logging.StreamHandler(sys.stdout),
    ],
) 

logger = logging.getLogger("youtubeRenderer")


import setuptools 

with open("README.md","r",encoding="utf-8") as f:
    long_description = f.read() 

__version__= "0.0.1"  

REPO_NAME = "youtube-renderer-pypi-package"
AUTHOR_USER_NAME = "amanullah20"
AUTHOR_EMAIL = "ullah.aman1@gmail.com"
SRC_REPO = "youtubeRenderer" 

setuptools.setup(
    name=SRC_REPO,
    version=__version__,
    author=AUTHOR_USER_NAME,
    author_email=AUTHOR_EMAIL,
    description="A small python package",
    long_description=long_description,
    long_description_content="text/markdown",
    url = f"https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}",
    project_url={
        "Bug Tracker": f"https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}/issues"
    },
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src")
)